@@ -27,21 +27,21 @@ N_ = gpodder.ngettext
 from gpodder import util
 
 from gpodder.gtkui.interface.common import BuilderWidget
-from gpodder.gtkui.interface.common import Orientation
 from gpodder.gtkui.frmntl.portrait import FremantleRotation
 
 import hildon
 
 class gPodderPreferences(BuilderWidget):
     UPDATE_INTERVALS = (
-            (0, _('manually')),
-            (20, N_('every %d minute', 'every %d minutes', 20) % 20),
-            (60, _('hourly')),
-            (60*6, N_('every %d hour', 'every %d hours', 6) % 6),
-            (60*24, _('daily')),
+            (0, _('Manually')),
+            (20, N_('Every %d minute', 'Every %d minutes', 20) % 20),
+            (60, _('Hourly')),
+            (60*6, N_('Every %d hour', 'Every %d hours', 6) % 6),
+            (60*24, _('Daily')),
     )
 
     DOWNLOAD_METHODS = (
+            ('quiet', _('Do nothing')),
             ('never', _('Show episode list')),
             ('queue', _('Add to download list')),
 #            ('wifi', _('Download when on Wi-Fi')),
@@ -59,11 +59,13 @@ class gPodderPreferences(BuilderWidget):
     )
 
     def new(self):
-        self.main_window.connect('destroy', lambda w, self: self.callback_finished(), self)
-        self.wiki_button = self.main_window.add_button(_('User manual'), 1)
-        self.wiki_button.connect('clicked', self.on_wiki_activate)
-        self.about_button = self.main_window.add_button(_('About'), 2)
-        self.about_button.connect('clicked', self.on_itemAbout_activate)
+        # Store the current configuration options in case we cancel later
+        self._config_backup = self._config.get_backup()
+        self._do_restore_config = True
+        self.main_window.connect('destroy', self.on_destroy)
+
+        self.save_button = self.main_window.add_button(gtk.STOCK_SAVE, 1)
+        self.save_button.connect('clicked', self.on_save_button_clicked)
 
         self.touch_selector_orientation = hildon.TouchSelector(text=True)
         for caption in FremantleRotation.MODE_CAPTIONS:
@@ -86,7 +88,7 @@ class gPodderPreferences(BuilderWidget):
             self.touch_selector_interval.set_active(0, minute_index_mapping[interval])
         else:
             self._custom_interval = self._config.auto_update_frequency
-            self.touch_selector_interval.append_text(_('every %d minutes') % interval)
+            self.touch_selector_interval.append_text(N_('Every %d minute', 'Every %d minutes', interval) % interval)
             self.touch_selector_interval.set_active(0, len(self.UPDATE_INTERVALS))
         self.picker_interval.set_selector(self.touch_selector_interval)
 
@@ -103,41 +105,42 @@ class gPodderPreferences(BuilderWidget):
         self.touch_selector_download.set_active(0, download_method_mapping[self._config.auto_download])
         self.picker_download.set_selector(self.touch_selector_download)
 
+        # Determine possible audio and video players (only installed ones)
+        self.audio_players = [(c, l) for c, l in self.AUDIO_PLAYERS if c == 'default' or util.find_command(c)]
+        self.video_players = [(c, l) for c, l in self.VIDEO_PLAYERS if c == 'default' or util.find_command(c)]
+
         # Create a mapping from audio players to touch selector indices
-        audio_player_mapping = dict((b, a) for a, b in enumerate(x[0] for x in self.AUDIO_PLAYERS))
+        audio_player_mapping = dict((b, a) for a, b in enumerate(x[0] for x in self.audio_players))
 
         self.touch_selector_audio_player = hildon.TouchSelector(text=True)
-        for value, caption in self.AUDIO_PLAYERS:
+        for value, caption in self.audio_players:
             self.touch_selector_audio_player.append_text(caption)
 
-        if self._config.player not in (x[0] for x in self.AUDIO_PLAYERS):
-            self._config.player = self.AUDIO_PLAYERS[0][0]
+        if self._config.player not in (x[0] for x in self.audio_players):
+            self._config.player = self.audio_players[0][0]
 
         self.touch_selector_audio_player.set_active(0, audio_player_mapping[self._config.player])
         self.picker_audio_player.set_selector(self.touch_selector_audio_player)
 
         # Create a mapping from video players to touch selector indices
-        video_player_mapping = dict((b, a) for a, b in enumerate(x[0] for x in self.VIDEO_PLAYERS))
+        video_player_mapping = dict((b, a) for a, b in enumerate(x[0] for x in self.video_players))
 
         self.touch_selector_video_player = hildon.TouchSelector(text=True)
-        for value, caption in self.VIDEO_PLAYERS:
+        for value, caption in self.video_players:
             self.touch_selector_video_player.append_text(caption)
 
-        if self._config.videoplayer not in (x[0] for x in self.VIDEO_PLAYERS):
-            self._config.videoplayer = self.VIDEO_PLAYERS[0][0]
+        if self._config.videoplayer not in (x[0] for x in self.video_players):
+            self._config.videoplayer = self.video_players[0][0]
 
         self.touch_selector_video_player.set_active(0, video_player_mapping[self._config.videoplayer])
         self.picker_video_player.set_selector(self.touch_selector_video_player)
 
-        self.update_button_mygpo()
-
         # Fix the styling and layout of the picker buttons
         for button in (self.picker_orientation, \
                        self.picker_interval, \
                        self.picker_download, \
                        self.picker_audio_player, \
-                       self.picker_video_player, \
-                       self.button_mygpo):
+                       self.picker_video_player):
             # Work around Maemo bug #4718
             button.set_name('HildonButton-finger')
             # Fix alignment problems (Maemo bug #6205)
@@ -145,27 +148,28 @@ class gPodderPreferences(BuilderWidget):
             child = button.get_child()
             child.set_padding(0, 0, 12, 0)
 
-        self.check_feed_update_skipping = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        self.check_feed_update_skipping.set_label(_('Enable feed update heuristics'))
-        self._config.connect_gtk_togglebutton('feed_update_skipping', self.check_feed_update_skipping)
-        self.pannable_vbox.add(self.check_feed_update_skipping)
-        self.pannable_vbox.reorder_child(self.check_feed_update_skipping, 6)
+        self.button_enable_mygpo.set_name('HildonCheckButton-finger')
 
         self.check_view_all_episodes = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.check_view_all_episodes.set_label(_('Show "All episodes" view'))
-        self._config.connect_gtk_togglebutton('podcast_list_view_all', self.check_view_all_episodes)
+        self.check_view_all_episodes.set_active(self._config.podcast_list_view_all)
         self.pannable_vbox.add(self.check_view_all_episodes)
         self.pannable_vbox.reorder_child(self.check_view_all_episodes, 2)
 
-        self.gPodderPreferences.show_all()
+        # Disable capitalization word completion
+        self.entry_mygpo_username.set_property('hildon-input-mode', \
+                gtk.HILDON_GTK_INPUT_MODE_FULL)
+        self.entry_mygpo_password.set_property('hildon-input-mode', \
+                gtk.HILDON_GTK_INPUT_MODE_FULL)
 
-    def on_window_orientation_changed(self, orientation):
-        if orientation == Orientation.PORTRAIT:
-            self.wiki_button.hide()
-            self.about_button.hide()
-        else:
-            self.wiki_button.show()
-            self.about_button.show()
+        self.entry_mygpo_password.set_visibility(False)
+
+        self.button_enable_mygpo.set_active(self._config.mygpo_enabled)
+        self.entry_mygpo_username.set_text(self._config.mygpo_username)
+        self.entry_mygpo_password.set_text(self._config.mygpo_password)
+        self.entry_mygpo_device.set_text(self._config.mygpo_device_caption)
+
+        self.gPodderPreferences.show_all()
 
     def on_picker_orientation_value_changed(self, *args):
         self._config.rotation_mode = self.touch_selector_orientation.get_active(0)
@@ -190,21 +194,32 @@ class gPodderPreferences(BuilderWidget):
 
     def on_picker_audio_player_value_changed(self, *args):
         active_index = self.touch_selector_audio_player.get_active(0)
-        new_value = self.AUDIO_PLAYERS[active_index][0]
+        new_value = self.audio_players[active_index][0]
         self._config.player = new_value
 
     def on_picker_video_player_value_changed(self, *args):
         active_index = self.touch_selector_video_player.get_active(0)
-        new_value = self.VIDEO_PLAYERS[active_index][0]
+        new_value = self.video_players[active_index][0]
         self._config.videoplayer = new_value
 
-    def update_button_mygpo(self):
-        if self._config.mygpo_username:
-            self.button_mygpo.set_value(self._config.mygpo_username)
+    def on_destroy(self, window):
+        if self._do_restore_config:
+            self._config.restore_backup(self._config_backup)
         else:
-            self.button_mygpo.set_value(_('Not logged in'))
+            self._config.podcast_list_view_all = self.check_view_all_episodes.get_active()
+            self._config.mygpo_enabled = self.button_enable_mygpo.get_active()
+            self._config.mygpo_username = self.entry_mygpo_username.get_text()
+            self._config.mygpo_password = self.entry_mygpo_password.get_text()
+            self._config.mygpo_device_caption = self.entry_mygpo_device.get_text()
 
-    def on_button_mygpo_clicked(self, button):
-        self.mygpo_login()
-        self.update_button_mygpo()
+            # Make sure the device is successfully created/updated
+            self.mygpo_client.create_device()
+            # Flush settings for mygpo client now
+            self.mygpo_client.flush(now=True)
+
+        self.callback_finished()
+
+    def on_save_button_clicked(self, button):
+        self._do_restore_config = False
+        self.main_window.destroy()
 
