@@ -28,7 +28,14 @@
 # For Python 2.5, we need to request the "with" statement
 from __future__ import with_statement
 
-import sqlite3.dbapi2 as sqlite
+try:
+    import sqlite3.dbapi2 as sqlite
+except ImportError:
+    try:
+        from pysqlite2 import dbapi2 as sqlite
+    except ImportError:
+        raise Exception('Please install SQLite3 support.')
+
 
 import threading
 
@@ -43,8 +50,11 @@ class Store(object):
     def _set(self, o, slot, value):
         # Set a slot on the given object to value, doing a cast if
         # necessary. The value None is special-cased and never cast.
+        cls = o.__class__.__slots__[slot]
         if value is not None:
-            value = o.__class__.__slots__[slot](value)
+            if isinstance(value, unicode):
+                value = value.decode('utf-8')
+            value = cls(value)
         setattr(o, slot, value)
 
     def commit(self):
@@ -88,9 +98,14 @@ class Store(object):
             table, slots = self._schema(o.__class__)
 
             # Only save values that have values set (non-None values)
-            slots = [s for s in slots if getattr(o, s) is not None]
+            slots = [s for s in slots if getattr(o, s, None) is not None]
 
-            values = [str(getattr(o, slot)) for slot in slots]
+            def convert(v):
+                if isinstance(v, str) or isinstance(v, unicode):
+                    return v
+                else:
+                    return str(v)
+            values = [convert(getattr(o, slot)) for slot in slots]
             self.db.execute('INSERT INTO %s (%s) VALUES (%s)' % (table,
                 ', '.join(slots), ', '.join('?'*len(slots))), values)
 
@@ -128,7 +143,7 @@ class Store(object):
                 for attr, value in zip(slots, row):
                     self._set(o, attr, value)
                 return o
-            return [apply(row) for row in cur.fetchall()]
+            return [apply(row) for row in cur]
 
     def get(self, class_, **kwargs):
         result = self.load(class_, **kwargs)
